@@ -606,9 +606,11 @@ class PortfolioDataApi(metaclass=Singleton):
             print(f'Failed to get data <err_msg> {e} from portfolio.get_port_fund_list')
             return []
 
-    def get_port_fund_pos_date(self,fund_id, trade_history, index_id): 
+    def get_port_fund_pos_date(self,fund_id, trade_history,benchmark_id_info): 
         try:
             order_list, fund_type = self.trade_history_parse(trade_history)
+            fund_type_dic = { vi: benchmark_id_info[k] for k, v in fund_type.items() for vi in v}
+            index_id = fund_type_dic[fund_id]
             basic = BasicDataApi()
             fund_list = [fund_id]
             fund_info = self.get_part_fund_info(fund_list=fund_list)
@@ -659,6 +661,8 @@ class PortfolioDataApi(metaclass=Singleton):
                 dic['end_date'] = str(dic['end_date'])
                 result.append(dic)
             nav_df.index.name = 'datetime'
+            nav_df = nav_df / nav_df.iloc[0]
+            nav_df.loc[:,'价格比'] = nav_df[fund_id] / nav_df[index_id]
             data = {
                 '净值':nav_df.rename(columns=desc_name_dic),
                 '持有期':result}
@@ -854,7 +858,7 @@ class PortfolioDataApi(metaclass=Singleton):
 
     def get_port_rolling_beta_index_info(self):
         try:
-            index_info = BasicDataApi().get_asset_info_real(real_id_list=['hs300','csi500'])
+            index_info = BasicDataApi().get_asset_info_real(real_id_list=['hs300','csi500','national_debt']).drop_duplicates(subset='real_id')
             res = []
             for r in index_info.itertuples():
                 res.append([r.asset_id, r.real_name])
@@ -1032,11 +1036,15 @@ class PortfolioDataApi(metaclass=Singleton):
             fund_nav = data['净值']
             res_status = Calculator.get_stat_result(dates=fund_nav.index, values=fund_nav['组合'])
             dic = {
-                'annual_ret':round(res_status.annualized_ret,4),
-                'annual_vol':round(res_status.annualized_vol,4),
-                'mdd':round(res_status.mdd,4),
+                '年化收益':round(res_status.annualized_ret,4),
+                '年化波动':round(res_status.annualized_vol,4),
+                '最大回撤':round(res_status.mdd,4),
+                '夏普比率':round(res_status.sharpe,2),
+                '近一周收益':round(res_status.recent_1w_ret,4),
+                '近一月收益':round(res_status.recent_1m_ret,4),
+                '创建日期':str(res_status.start_date),
+                '当前回撤':round(res_status.recent_drawdown,4),
             }
-
             fund_weight = data['各基权重'].tail(1).dropna(axis=1).T
             fund_weight.columns = ['weight']
             result = {}
