@@ -12,11 +12,12 @@ import pandas as pd
 from sqlalchemy.orm import sessionmaker
 
 from ...util.singleton import Singleton
-from ...constant import FOFTradeStatus, DividendCalcMethod
+from ...constant import FOFTradeStatus, DividendCalcMethod, EMailParserType
 from ..view.derived_models import HedgeFundInvestorPurAndRedemp, HedgeFundInvestorDivAndCarry, HedgeFundCustodianData
 from ..wrapper.mysql import DerivedDatabaseConnector
 from ..api.basic import BasicDataApi
 from ..api.derived import DerivedDataApi
+from ..nav_reader.parser_runner import ParserRunner
 
 
 class HedgeFundDataManager(metaclass=Singleton):
@@ -99,7 +100,7 @@ class HedgeFundDataManager(metaclass=Singleton):
                     if one['acc_unit_value'] >= row.acc_unit_value:
                         # 当前水位线未超过该笔份额的水位线 不需要计提业绩报酬
                         continue
-                    carry = self._calc_carry(row.acc_unit_value, one['acc_unit_value'], fof_info.incentive_fee_type, fof_info.incentive_fee_str) * one['share'] / row.net_asset_value
+                    carry = round(self._calc_carry(row.acc_unit_value, one['acc_unit_value'], fof_info.incentive_fee_type, fof_info.incentive_fee_str) * one['share'] / row.net_asset_value, 2)
                     assert one['share'] >= carry, f'!!!'
                     one['share'] -= carry
                     # 水位线变成本次计提时的水位线了
@@ -142,15 +143,15 @@ class HedgeFundDataManager(metaclass=Singleton):
         if event_type == FOFTradeStatus.PURCHASE:
             # 认购
             datas['purchase_amount'] = datas['amount']
-            datas['share_changed'] = (datas['amount'] + datas['raising_interest']) / datas['net_asset_value']
+            datas['share_changed'] = round((datas['amount'] + datas['raising_interest']) / datas['net_asset_value'], 2)
         elif event_type == FOFTradeStatus.SUBSCRIBE:
             # 申购
             datas['purchase_amount'] = datas['amount']
-            datas['share_changed'] = datas['amount'] / datas['net_asset_value']
+            datas['share_changed'] = round(datas['amount'] / datas['net_asset_value'], 2)
         elif event_type == FOFTradeStatus.REDEEM:
             # 赎回
             datas['share_changed'] = -datas['redemp_share']
-            datas['redemp_confirmed_amount'] = datas['redemp_share'] * datas['net_asset_value'] - datas['redemp_fee']
+            datas['redemp_confirmed_amount'] = round(datas['redemp_share'] * datas['net_asset_value'], 2) - datas['redemp_fee']
 
             # 计算业绩报酬计提
             carry_sum = 0
@@ -161,12 +162,12 @@ class HedgeFundDataManager(metaclass=Singleton):
                 if one['share'] >= datas['redemp_share']:
                     one['share'] -= datas['redemp_share']
                     if datas['acc_unit_value'] > one['water_line']:
-                        carry_sum += self._calc_carry(datas['acc_unit_value'], one['water_line'], fof_info.incentive_fee_type, fof_info.incentive_fee_str) * datas['redemp_share']
+                        carry_sum += round(self._calc_carry(datas['acc_unit_value'], one['water_line'], fof_info.incentive_fee_type, fof_info.incentive_fee_str) * datas['redemp_share'], 2)
                     break
                 else:
                     datas['redemp_share'] -= one['share']
                     if datas['acc_unit_value'] > one['water_line']:
-                        carry_sum += self._calc_carry(datas['acc_unit_value'], one['water_line'], fof_info.incentive_fee_type, fof_info.incentive_fee_str) * one['share']
+                        carry_sum += round(self._calc_carry(datas['acc_unit_value'], one['water_line'], fof_info.incentive_fee_type, fof_info.incentive_fee_str) * one['share'], 2)
                     one['share'] = 0
             else:
                 assert False, 'not enough shares to redeem'
@@ -286,7 +287,7 @@ class HedgeFundDataManager(metaclass=Singleton):
             elif event_type == FOFTradeStatus.DIVIDEND_VOLUME:
                 # 红利再投
                 datas['reinvest_amount'] = div - (datas['carry_amount'] if not pd.isnull(datas['carry_amount']) else 0)
-                datas['share_changed'] = datas['reinvest_amount'] / datas['net_asset_value']
+                datas['share_changed'] = round(datas['reinvest_amount'] / datas['net_asset_value'], 2)
                 datas['cash_dividend'] = 0
             else:
                 raise ValueError(f'invalid event_type {event_type}')
@@ -356,11 +357,11 @@ class HedgeFundDataManager(metaclass=Singleton):
             dividend_amount = datas['dividend_for_calc']
         elif calc_method == DividendCalcMethod.BY_PER_UNIT:
             # 每单位红利
-            dividend_amount = total_share * datas['dividend_for_calc']
+            dividend_amount = round(total_share * datas['dividend_for_calc'], 2)
         else:
             raise ValueError(f'invalid calc_method {calc_method}')
 
-        s = dividend_amount * weight
+        s = (dividend_amount * weight).round(2)
         event_type = datas['event_type']
         if datas['event_type'] == FOFTradeStatus.DIVIDEND_CASH:
             # 现金分红
@@ -369,7 +370,7 @@ class HedgeFundDataManager(metaclass=Singleton):
             if 'do_deduct_reward' in datas and datas['do_deduct_reward']:
                 carry_df = self.calc_carry_event(datas)
                 df = df.join(carry_df.set_index('investor_id').carry_amount)
-                df['cash_dividend'] -= df.carry_amount
+                df['cash_dividend'] -= df.carry_amount.round(2)
             else:
                 df['carry_amount'] = np.nan
             df['share_changed'] = 0
@@ -381,10 +382,10 @@ class HedgeFundDataManager(metaclass=Singleton):
             if 'do_deduct_reward' in datas and datas['do_deduct_reward']:
                 carry_df = self.calc_carry_event(datas)
                 df = df.join(carry_df.set_index('investor_id').carry_amount)
-                df['reinvest_amount'] -= df.carry_amount
+                df['reinvest_amount'] -= df.carry_amount.round(2)
             else:
                 df['carry_amount'] = np.nan
-            df['share_changed'] = df.reinvest_amount / datas['net_asset_value']
+            df['share_changed'] = (df.reinvest_amount / datas['net_asset_value']).round(2)
             df['cash_dividend'] = 0
         else:
             raise ValueError(f'invalid event_type {event_type}')
@@ -435,8 +436,8 @@ class HedgeFundDataManager(metaclass=Singleton):
                 if one['water_line'] >= datas['acc_unit_value']:
                     # 当前水位线未超过该笔份额的水位线 不需要计提业绩报酬
                     continue
-                carry_amount = self._calc_carry(datas['acc_unit_value'], one['water_line'], fof_info.incentive_fee_type, fof_info.incentive_fee_str) * one['share']
-                carry = carry_amount / datas['net_asset_value']
+                carry_amount = round(self._calc_carry(datas['acc_unit_value'], one['water_line'], fof_info.incentive_fee_type, fof_info.incentive_fee_str) * one['share'], 2)
+                carry = round(carry_amount / datas['net_asset_value'], 2)
                 assert one['share'] >= carry, f'!!!'
                 carry_amount_sum += carry_amount
                 share_changed -= carry
@@ -476,99 +477,15 @@ class HedgeFundDataManager(metaclass=Singleton):
         throw excepion if failed, or return a datetime.date if succeed
         '''
 
-        def _transform_hedge_fund_id(x: str):
-            fund_id = x.split()[0].split('.')[-1]
-            real_fund_id = BasicDataApi().get_hedge_fund_alias(manager_id, fund_id)
-            if real_fund_id is not None and not real_fund_id.empty:
-                return real_fund_id.fund_id.array[0]
-            else:
-                return fund_id
+        parser_runner = ParserRunner(manager_id, EMailParserType.E_PARSER_VALUATION)
+        total_df = parser_runner.parse_data(datas, manager_id)
+        if total_df is None:
+            raise Exception(f'could not parse this custodian data (manager_id){manager_id} (fof_id){fof_id}')
 
-        to_parse_date = pd.read_excel(datas, skiprows=3, nrows=1).columns.array[0]
-        the_date = re.findall(r'[0-9\-]+', to_parse_date)
-        assert the_date, f'parse date failed (info){to_parse_date}'
-        the_date = pd.to_datetime(the_date[0], infer_datetime_format=True).date()
-
-        df = pd.read_excel(datas, header=4, index_col=0)
-        df = df.loc[df.index.notna(), :]
-        df = df.rename(columns={'Unnamed: 7': '成本.1', 'Unnamed: 11': '市值.1', 'Unnamed: 14': '估值增值.1'})
-        print(df)
-        equity = df.at['资产净值', '市值.1']
-        total_shares = df.at['实收资本', '数量']
-
-        mutual_funds_part1 = df.loc[(df.index > '1105.21.01') & (df.index < '1105.24'), ['科目名称', '数量', '市值.1', '行情']]
-        mutual_funds_part1 = mutual_funds_part1.reset_index(drop=True)
-        mutual_funds_part2 = df.loc[(df.index > '1105.24.01') & (df.index < '1108'), ['科目名称', '数量', '市值.1', '行情']]
-        mutual_funds_part2 = mutual_funds_part2.reset_index(drop=True)
-        mutual_funds = pd.concat([mutual_funds_part1, mutual_funds_part2], ignore_index=True).rename(columns={
-            '科目名称': 'fund_id',
-            '数量': 'shares',
-            '市值.1': 'mv',
-            '行情': 'nav',
-        })
-        mutual_funds['fund_id'] = mutual_funds.fund_id.map(lambda x: x + '!0')
-
-        hedge_funds = df.loc[(df.index > '1108.02.01') & (df.index < '1203'), ['数量', '市值.1', '行情']]
-        hedge_funds['fund_id'] = hedge_funds.index.map(_transform_hedge_fund_id)
-        hedge_funds = hedge_funds.reset_index(drop=True).rename(columns={
-            '数量': 'shares',
-            '市值.1': 'mv',
-            '行情': 'nav',
-        })
-
-        deposit_in_bank = df.at['1002', '市值.1']
-        interest_receivable = df.at['1204', '市值.1']
-        try:
-            pur_amt_receivable = df.at['1207', '市值.1']
-        except KeyError:
-            pur_amt_receivable = np.nan
-        try:
-            sec_clearing_fund = df.at['3003', '市值.1']
-        except KeyError:
-            sec_clearing_fund = np.nan
-        try:
-            dividends_receivable = df.at['1203', '市值.1']
-        except KeyError:
-            dividends_receivable = np.nan
-        payable_to_managers = df.at['2206', '市值.1']
-        payable_to_custodian = df.at['2207', '市值.1']
-        payable_to_admin_service = 0
-        got_the_item = False
-        for subject in ('2215', '2206.14'):
-            try:
-                payable_to_admin_service += df.at[subject, '市值.1']
-                got_the_item = True
-            except KeyError:
-                pass
-        other_assets = deposit_in_bank + interest_receivable + (pur_amt_receivable if not pd.isnull(pur_amt_receivable) else 0) + (sec_clearing_fund if not pd.isnull(sec_clearing_fund) else 0) + (dividends_receivable if not pd.isnull(dividends_receivable) else 0) - (payable_to_managers + payable_to_custodian + payable_to_admin_service)
-        if not got_the_item:
-            payable_to_admin_service = np.nan
-
-        nav = float(df.loc['今日单位净值', '科目名称'])
-        total_df = pd.Series({
-            'fof_id': fof_id,
-            'manager_id': manager_id,
-            'datetime': the_date,
-            'nav': nav,
-            'equity': equity,
-            'total_shares': total_shares,
-            'other_assets': other_assets,
-            'deposit_in_bank': deposit_in_bank,
-            'interest_receivable': interest_receivable,
-            'pur_amt_receivable': pur_amt_receivable,
-            'sec_clearing_fund': sec_clearing_fund,
-            'dividends_receivable': dividends_receivable,
-            'payable_to_managers': payable_to_managers,
-            'payable_to_custodian': payable_to_custodian,
-            'payable_to_admin_service': payable_to_admin_service,
-            'mutual_funds_data': mutual_funds.to_json(orient='records'),
-            'hedge_funds_data': hedge_funds.to_json(orient='records'),
-        })
-        total_df = total_df.to_frame().T
-        # total_df = total_df.infer_objects()
+        total_df['fof_id'] = fof_id
         now_df = DerivedDataApi().get_hedge_fund_custodian_data(manager_id=manager_id, fof_id_list=[fof_id])
         if now_df is not None:
-            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted']).replace({None: np.nan}).astype(total_df.dtypes.to_dict())
+            now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted', 'id', 'url']).replace({None: np.nan}).astype(total_df.dtypes.to_dict())
             # merge on all columns
             df = total_df.round(6).merge(now_df.round(6), how='left', indicator=True, validate='one_to_one')
             df = df[df._merge == 'left_only'].drop(columns=['_merge'])
@@ -579,7 +496,7 @@ class HedgeFundDataManager(metaclass=Singleton):
             for row in df.itertuples(index=False):
                 DerivedDataApi().delete_hedge_fund_custodian_data(row.manager_id, row.fof_id, row.datetime)
             df.to_sql(HedgeFundCustodianData.__table__.name, DerivedDatabaseConnector().get_engine(), index=False, if_exists='append')
-        return the_date
+        return total_df['datetime'].array[0]
 
     @staticmethod
     def calc_whole_adjusted_net_value(nav_acc_data: pd.DataFrame) -> pd.DataFrame:
