@@ -15,10 +15,10 @@ from ...util.wechat_bot import WechatBot
 from ...util.calculator import Calculator
 from ...constant import EMailParserType
 from ..wrapper.mysql import BasicDatabaseConnector, DerivedDatabaseConnector
+from ..view.basic_models import FOFInfo
 from ..view.derived_models import FOFUnconfirmedNav, FOFNav
 from ..api.basic import BasicDataApi
 from ..api.derived import DerivedDataApi
-from ..view.basic_models import FOFInfo
 from .parser_runner import ParserRunner
 
 
@@ -86,6 +86,15 @@ class FOFNAVReader:
             try:
                 df = df.drop(columns=['fof_name'], errors='ignore')
                 df['manager_id'] = self._manager_id
+
+                def _transform_fof_id(x: str) -> str:
+                    real_fof_id = BasicDataApi().get_hedge_fund_alias(self._manager_id, x)
+                    if real_fof_id is not None and not real_fof_id.empty:
+                        return real_fof_id.fund_id.array[0]
+                    else:
+                        return x
+                df['fof_id'] = df.fof_id.map(_transform_fof_id)
+
                 r1 = self._dump_hedge_to_db(df[df.fof_id.isin(self._hedge_list)])
                 if r1 is not None:
                     df_list.append(r1)
@@ -174,7 +183,7 @@ class FOFNAVReader:
             now_df = now_df.drop(columns=['update_time', 'create_time', 'is_deleted', 'ta_factor', 'volume', 'mv', 'ret']).sort_values(by=['manager_id', 'fof_id', 'datetime']).drop_duplicates(subset=['manager_id', 'fof_id', 'datetime'], keep='last')
             now_df = now_df.astype({'nav': 'float64', 'acc_net_value': 'float64', 'adjusted_nav': 'float64'})
             df = df.reindex(columns=now_df.columns).astype(now_df.dtypes.to_dict())
-            df = df.merge(now_df, how='left', on=['manager_id', 'fof_id', 'datetime', 'nav', 'acc_net_value', 'adjusted_nav'], indicator=True, validate='one_to_one')
+            df = df.round(6).merge(now_df.round(6), how='left', on=['manager_id', 'fof_id', 'datetime', 'nav', 'acc_net_value', 'adjusted_nav'], indicator=True, validate='one_to_one')
             df = df[df._merge == 'left_only'].drop(columns=['_merge'])
             if df.empty:
                 return
