@@ -1,20 +1,26 @@
 
 
-from typing import Optional
+from typing import Optional, Dict
 # import datetime
 import os
 import traceback
 import time
 import tarfile
 
+from sqlalchemy.orm import sessionmaker
 import pandas as pd
+import numpy as np
 
 from ...util.mail_retriever import MailAttachmentRetriever, IMAP_SPType, UID_FILE_NAME
 from ...util.wechat_bot import WechatBot
-from ..wrapper.mysql import RawDatabaseConnector
+from ...util.calculator import Calculator
+from ..wrapper.mysql import RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector
 from ..api.raw import RawDataApi
 from ..api.basic import BasicDataApi
+from ..api.derived import DerivedDataApi
 from ..view.raw_models import HFIndexPrice, HFFundNav
+from ..view.basic_models import FOFInfo
+from ..view.derived_models import FOFNavPublic
 from ..fund.raw.other_raw_data_downloader import OtherRawDataDownloader
 from ..fund.raw.raw_data_helper import RawDataHelper
 
@@ -33,7 +39,8 @@ class ResearchNAVReader:
         self._wechat_bot = WechatBot()
 
     @staticmethod
-    def _read_for_NAVData(file_path: str) -> pd.DataFrame:
+    def _read_for_NAVData(file_path: str) -> Dict[str, int]:
+        update_info: Dict[str, int] = {}
         tar = tarfile.open(file_path, 'r:gz', encoding='gb2312')
         for one in tar:
             if not one.name.endswith('.xls') and not one.name.endswith('.xlsx'):
@@ -74,21 +81,63 @@ class ResearchNAVReader:
                 df['datetime'] = pd.to_datetime(df.datetime, infer_datetime_format=True).dt.date
                 hf_fund_nav = RawDataApi().get_hf_fund_nav(fund_ids=[fund_id])
                 if hf_fund_nav is not None:
-                    df = df.astype(hf_fund_nav.dtypes.to_dict())
+                    df_fitted = df.astype(hf_fund_nav.dtypes.to_dict())
                     # merge on all columns
-                    df = df.merge(hf_fund_nav, how='left', indicator=True, validate='one_to_one')
-                    df = df[df._merge == 'left_only'].drop(columns=['_merge'])
-                print(df)
+                    df_fitted = df_fitted.merge(hf_fund_nav, how='left', indicator=True, validate='one_to_one')
+                    df_fitted = df_fitted[df_fitted._merge == 'left_only'].drop(columns=['_merge'])
+                else:
+                    df_fitted = df
+                print(f'to hf_fund_nav {df_fitted}')
                 # TODO: 最好原子提交下边两步
-                RawDataApi().delete_hf_fund_nav(fund_id_to_delete=fund_id, datetime_list=df.datetime.to_list())
+                RawDataApi().delete_hf_fund_nav(fund_id_to_delete=fund_id, datetime_list=df_fitted.datetime.to_list())
                 # 更新到db
-                df.to_sql(HFFundNav.__table__.name, RawDatabaseConnector().get_engine(), index=False, if_exists='append')
-            except Exception:
+                df_fitted.to_sql(HFFundNav.__table__.name, RawDatabaseConnector().get_engine(), index=False, if_exists='append')
+
+                # 再向 FOFNavPublic 更新一份
+                df = df.rename(columns={'fund_id': 'fof_id', 'nav': 'adjusted_nav'})
+                df['nav'] = np.nan
+                df['acc_net_value'] = np.nan
+                fof_nav_public = DerivedDataApi().get_fof_nav_public(fof_id_list=[fund_id])
+                if fof_nav_public is not None:
+                    fof_nav_public = fof_nav_public.drop(columns=['volume', 'mv', 'ret', 'create_time', 'update_time', 'is_deleted'])
+                    df = df.astype(fof_nav_public.dtypes.to_dict())
+                    # merge on all columns
+                    df = df.merge(fof_nav_public, how='left', indicator=True, validate='one_to_one')
+                    df = df[df._merge == 'left_only'].drop(columns=['_merge'])
+                print(f'to fof_nav_public {df}')
+                # TODO: 最好原子提交下边两步
+                DerivedDataApi().delete_fof_nav_public(fof_id_to_delete=fund_id, datetime_list=df.datetime.to_list())
+                # 更新到db
+                df.to_sql(FOFNavPublic.__table__.name, DerivedDatabaseConnector().get_engine(), index=False, if_exists='append')
+                update_info[p_name] = df.shape[0]
+
+                fof_nav_public = DerivedDataApi().get_fof_nav_public(fof_id_list=[fund_id])
+                if fof_nav_public is not None:
+                    fof_nav_public = fof_nav_public.set_index('datetime')['adjusted_nav']
+                    res_status = Calculator.get_stat_result(fof_nav_public.index, fof_nav_public.array)
+                    Session = sessionmaker(BasicDatabaseConnector().get_engine())
+                    db_session = Session()
+                    # '1' 表示公有的 FOFInfo
+                    fof_info_to_set = db_session.query(FOFInfo).filter(FOFInfo.manager_id == '1', FOFInfo.fof_id == fund_id).one_or_none()
+                    fof_info_to_set.net_asset_value = float(res_status.last_unit_nav) if not pd.isnull(res_status.last_unit_nav) else None
+                    fof_info_to_set.adjusted_net_value = float(fof_nav_public.array[-1]) if not pd.isnull(fof_nav_public.arraay[-1]) else None
+                    fof_info_to_set.latest_cal_date = res_status.end_date
+                    fof_info_to_set.ret_year_to_now = float(res_status.recent_year_ret) if not pd.isnull(res_status.recent_year_ret) else None
+                    fof_info_to_set.ret_total = float(res_status.cumu_ret) if not pd.isnull(res_status.cumu_ret) else None
+                    fof_info_to_set.ret_ann = float(res_status.annualized_ret) if not pd.isnull(res_status.annualized_ret) else None
+                    fof_info_to_set.mdd = float(res_status.mdd) if not pd.isnull(res_status.mdd) else None
+                    fof_info_to_set.sharpe = float(res_status.sharpe) if not pd.isnull(res_status.sharpe) else None
+                    fof_info_to_set.vol = float(res_status.annualized_vol) if not pd.isnull(res_status.annualized_vol) else None
+                    db_session.commit()
+                    db_session.close()
+            except Exception as e:
                 traceback.print_exc()
+                print(f'[_read_for_NAVData] failed (err){e}')
         tar.close()
+        return update_info
 
     @staticmethod
-    def _read_for_IndexData(file_path: str):
+    def _read_for_IndexData(file_path: str) -> Dict[str, int]:
         update_info = {}
         tar = tarfile.open(file_path, 'r:gz', encoding='gb2312')
         for one in tar:
@@ -161,13 +210,17 @@ class ResearchNAVReader:
 
             try:
                 if '净值数据' in name:
-                    ResearchNAVReader._read_for_NAVData(file_path)
+                    update_info = ResearchNAVReader._read_for_NAVData(file_path)
 
                     ordd = OtherRawDataDownloader(RawDataHelper())
                     ret = ordd.hf_fund_nav_miss()
                     assert not ret, 'update table of hf fund nav miss failed!!'
+
+                    self._wechat_bot.send_research_data_update('净值', update_info)
                 elif '指数数据' in name:
                     update_info = ResearchNAVReader._read_for_IndexData(file_path)
+
+                    self._wechat_bot.send_research_data_update('指数', update_info)
                 else:
                     raise NotImplementedError('unknown research nav file from attachment')
             except Exception as e:
