@@ -948,6 +948,7 @@ class FOFInfo(FOFBase):
     main_fof_id = Column(VARCHAR(32))                       # 主ID
     last_increase_rate = Column(DOUBLE(asdecimal=False))    # 涨跌幅
     last_before_date = Column(DATE)                         # 前净值日
+    has_nav = Column(BOOLEAN, default=False)                # 是否存在净值
 
 
 class FOFScaleAlteration(FOFBase):
@@ -1218,22 +1219,32 @@ class FOFAssertCorrect(FOFBase):
 
 
 class EMailParserInfo(FOFBase):
-    '''parser信息表'''
+    ''' parser 信息表'''
 
     __tablename__ = 'email_parser_info'
 
-    manager_id = Column(CHAR(32), primary_key=True)  # 管理端ID
-    p_id = Column(CHAR(16), primary_key=True)  # parser ID
+    id = Column(Integer, primary_key=True, autoincrement=True)  # parser ID
+    manager_id = Column(CHAR(32))  # 管理端ID
+    p_name = Column(TEXT)                      # parser name
     p_desc = Column(TEXT)                      # parser 描述
-    p_type = Column(Integer)                   # parser 类型
-    is_valid = Column(BOOLEAN)                 # parser 是否生效
+    p_type = Column(Integer, nullable=False)                   # parser 类型
 
 
 class EMailParserCode(FOFBase):
-    '''parser代码表'''
+    ''' parser 代码表'''
 
     __tablename__ = 'email_parser_code'
 
-    manager_id = Column(CHAR(32), primary_key=True)  # 管理端ID
-    p_id = Column(CHAR(16), primary_key=True)        # parser ID
-    p_code = Column(TEXT)                            # parser 代码
+    id = Column(Integer, primary_key=True, autoincrement=True)  # parser ID
+    manager_id = Column(CHAR(32))  # 管理端ID
+    p_code = Column(TEXT, nullable=False)                            # parser 代码
+
+
+class EMailParserExec(FOFBase):
+    ''' parser 执行信息'''
+
+    __tablename__ = 'email_parser_exec'
+
+    id = Column(Integer, primary_key=True, autoincrement=True)  # parser ID
+    manager_id = Column(CHAR(32), unique=True)  # 管理端ID
+    p_priority_info = Column(TEXT, nullable=False)                   # parser 优先级信息 JSON 格式
