@@ -63,7 +63,7 @@ class SeriesStatUnit:
     mdd_recover_date1: datetime.date    # 最大回撤恢复开始时间
     mdd_recover_date2: datetime.date    # 最大回测恢复结束时间
     mdd_recover_lens: int               # 最大回测哈恢复天数
-
+    win_rate_0_period: float            # 设定周期对零胜率
 
 @dataclasses.dataclass
 class BenchmarkSeiesStatUnit(SeriesStatUnit):
@@ -196,6 +196,7 @@ class Calculator:
             mdd_recover_date1=res['mdd_recover_date1'],
             mdd_recover_date2=res['mdd_recover_date2'],
             mdd_recover_lens=res['mdd_recover_lens'],
+            win_rate_0_period=res['win_rate_0_period'],
         )
 
     @staticmethod
@@ -292,6 +293,7 @@ class Calculator:
             mdd_recover_date1=res['mdd_recover_date1'],
             mdd_recover_date2=res['mdd_recover_date2'],
             mdd_recover_lens=res['mdd_recover_lens'],
+            win_rate_0_period=res['win_rate_0_period'],
         )
 
     @staticmethod
