@@ -459,6 +459,7 @@ class CalculatorBase:
             raise_month_num = sr_ret_monthly[sr_ret_monthly>0].shape[0]
             drop_month_num = sr_ret_monthly[sr_ret_monthly<0].shape[0]
             mdd_recover, mdd_recover_date1, mdd_recover_date2, mdd_recover_lens = CalculatorBase.mdd_recover_analysis(values=values, dates=dates)
+            win_rate_0_period = np.mean((sr_ret > 0) * 1)
 
             if benchmark_values is not None:
                 assert len(dates) == len(benchmark_values), 'date and bench_values has different numbers'
@@ -630,6 +631,7 @@ class CalculatorBase:
                     'mdd_recover_date1':mdd_recover_date1,
                     'mdd_recover_date2':mdd_recover_date2,
                     'mdd_recover_lens':mdd_recover_lens,
+                    'win_rate_0_period':win_rate_0_period,
                 }
             else:
                 return {
@@ -677,6 +679,7 @@ class CalculatorBase:
                     'mdd_recover_date1':mdd_recover_date1,
                     'mdd_recover_date2':mdd_recover_date2,
                     'mdd_recover_lens':mdd_recover_lens,
+                    'win_rate_0_period':win_rate_0_period,
                 }
         else:
             return {
@@ -756,6 +759,7 @@ class CalculatorBase:
                     'mdd_recover_date1':dates[0] if len(dates) > 0 else None,
                     'mdd_recover_date2':dates[0] if len(dates) > 0 else None,
                     'mdd_recover_lens':0,
+                    'win_rate_0_period':0,
                 }
 
 
