@@ -8,9 +8,12 @@ import re
 from email.header import decode_header, make_header
 
 from typing import Dict, Optional, Tuple, Union
+from bs4 import BeautifulSoup
 import pandas as pd
 
 
+imaplib.Commands['ID'] = ('AUTH',)
+
 UID_FILE_NAME = 'mail_uid_recorder'
 
 
@@ -53,7 +56,12 @@ class MailAttachmentRetriever:
             df_list: Dict[str, pd.DataFrame] = {}
             with imaplib.IMAP4_SSL(host=host, port=port) as M:
                 M.login(user, pw)
-                M.select(mailbox='Inbox', readonly=True)
+                args = ("name", "PuyuanTech", "contact", "PuyuanTech", "version", "1.0.0", "vendor", "myclient")
+                id_arg = '" "'.join(args)
+                typ, dat = M._simple_command('ID', f'("{id_arg}")')
+                # print(M._untagged_response(typ, dat, 'ID'))
+                ret = M.select(mailbox='Inbox', readonly=True)
+                print(f'(select ret){ret}')
                 if last_uid is None:
                     criterion = 'ALL'
                 else:
@@ -97,33 +105,44 @@ class MailAttachmentRetriever:
                                             break
                     if not is_done:
                         for part in email_message.walk():
-                            if part.get_content_maintype() != 'multipart':
-                                if part.get('Content-Disposition') is None:
-                                    # 尝试解析正文
-                                    body = part.get_payload(decode=True)
-                                    pos_start = body.find(b'<table')
-                                    if pos_start != -1:
-                                        end_tag = b'</table'
-                                        pos_end = body.find(end_tag)
+                            if part.get('Content-Disposition') is None:
+                                # 尝试解析正文
+                                body = part.get_payload(decode=True)
+                                if body is None:
+                                    continue
+                                soup = BeautifulSoup(body, features='lxml')
+                                if soup.table is None:
+                                    continue
+
+                                for one in soup.findAll('meta', {'content': re.compile(r'.*charset.*')}):
+                                    encoding = re.findall(r'.*charset=(.*)', one.get('content'))
+                                    if encoding:
+                                        encoding = encoding[0]
+                                        break
+                                else:
+                                    encoding = 'gbk'
+                                try:
+                                    df = pd.read_html(str(soup.table), encoding=encoding)
+                                except Exception as e:
+                                    print(f'got exception when read html (exception){e}')
+                                else:
+                                    if df:
+                                        df = df[0]
+                                        subject = str(make_header(decode_header(email_message['Subject'])))
+                                        fund_id = re.findall(r'S[A-Z0-9]{5}', subject, flags=re.ASCII)
+                                        if fund_id and '产品代码' not in df.columns.array:
+                                            df['产品代码'] = fund_id[0]
+                                        real_name = f"{subject}_{encoding}.xlsx"
+                                        file_path = os.path.join(self._dump_dir, real_name)
                                         try:
-                                            df = pd.read_html(body[pos_start:pos_end+len(end_tag)], encoding='gbk')
-                                        except Exception as e:
-                                            print(f'got exception when read html (exception){e}')
-                                        else:
-                                            if df:
-                                                df = df[0]
-                                                subject = str(make_header(decode_header(email_message['Subject'])))
-                                                fund_id = re.findall(r'S[A-Z0-9]{5}', subject, flags=re.ASCII)
-                                                if fund_id and '产品代码' not in df.columns.array:
-                                                    df['产品代码'] = fund_id[0]
-                                                real_name = f"{subject}.xlsx"
-                                                file_path = os.path.join(self._dump_dir, real_name)
-                                                try:
-                                                    df.to_excel(file_path, index=False)
-                                                    df_list[real_name] = (uid, os.path.abspath(file_path))
-                                                    print(f'content {real_name} on {df_list[real_name]} done (uid){uid}')
-                                                except Exception as e:
-                                                    pass
+                                            if df.shape[0] <= 2:
+                                                df.to_excel(file_path, index=False)
+                                            else:
+                                                df.to_excel(file_path, header=None, index=False)
+                                            df_list[real_name] = (uid, os.path.abspath(file_path))
+                                            print(f'content {real_name} on {df_list[real_name]} done (uid){uid}')
+                                        except Exception:
+                                            pass
                 M.close()
             return df_list
         except Exception as e:
@@ -140,5 +159,5 @@ if __name__ == '__main__':
         import sys
         sys.exit(f'can not found enough params in env (e){e}')
 
-    mar = MailAttachmentRetriever(email_data_dir)
-    print(mar.get_excels(IMAP_SPType.IMAP_QQ, user_name, password, 496))
+    mar = MailAttachmentRetriever(email_data_dir, ['xls', 'xlsx', 'pdf'])
+    print(mar.get_excels(IMAP_SPType.IMAP_QQ, user_name, password, b'811'))
