@@ -120,18 +120,18 @@ class WechatBot(object):
     def send_update_factor_result(self, dt, tag, failed_factors: List[str]):
         markdown_content = f'#### {dt}'
         if failed_factors:
-            markdown_content += f'\n>**更新下列{tag} factor失败: <font color=\"warning\">{failed_factors}</font>**'
+            markdown_content += f'\n>**下列{tag} factor更新失败: <font color=\"warning\">{failed_factors}</font>**'
         else:
-            markdown_content += f'\n><font color=\"info\">更新所有{tag} factor成功</font>'
+            markdown_content += f'\n><font color=\"info\">所有{tag} factor更新成功</font>'
         self.send(markdown_content)
 
     def send_hedge_fund_nav_update(self, df: pd.DataFrame):
-        markdown_content = '#### <font color=\"info\">更新以下产品净值数据成功</font>'
+        markdown_content = '#### <font color=\"info\">以下产品净值数据更新成功</font>'
         markdown_content += f'\n>{df.to_markdown()}'
         self.send(markdown_content)
 
     def send_hedge_fund_nav_update_failed(self, err_msg: str):
-        markdown_content = '#### <font color=\"warning\">更新产品净值数据错误！！</font>'
+        markdown_content = '#### <font color=\"warning\">产品净值数据更新错误！！</font>'
         markdown_content += f'\n>**err msg:** {err_msg}'
         self.send(markdown_content)
 
@@ -211,6 +211,12 @@ class WechatBot(object):
         markdown_content += f'\n>**err msg:** {err_msg}'
         self.send(markdown_content)
 
+    def send_research_data_update(self, tag: str, datas: Dict[str, int]):
+        markdown_content = f'#### 研究数据({tag})更新成功({len(datas.keys())})'
+        for k, v in datas.items():
+            markdown_content += f'\n><font color=\"info\">{k}: </font>**{v}**'
+        self.send(markdown_content)
+
     def send_refinancing_key_info(self, dt, stocks, key):
         if stocks:
             markdown_content = f'#### {dt}'
